==> fillets-ng-data-0.7.1.tar.gz: fillets-ng-data-0.7.1/script/floppy/dialogs_cs.lua <==

dialogId("disk-v-tady", "font_big", "It looks as if we finally got there.")
dialogStr("Zdá se, že jsme konečně tady.")


dialogId("disk-m-tady", "font_small", "Do you think this is it?")
dialogStr("Myslíš si, že je to tady?")


dialogId("disk-m-vejit", "font_small", "How could it all fit on one three and a half inch floppy?")
dialogStr("Jak by se to mohlo vejít na jednu tři a půl palcovou disketu?")


dialogId("disk-v-metrova", "font_big", "Look how much bigger than me it is. It is a three and a half meter floppy.")
dialogStr("Podívej, o kolik je to větší než já. To je spíš třiceti pěti metrová disketa.")


dialogId("disk-m-velka", "font_small", "That`s better. Big plan, big disk. That makes sense.")
dialogStr("Tak to je lepší. Velký plán, velká disketa. To dává smysl.")


dialogId("disk-m-zvednem", "font_small", "Do you think we can lift it up?")
dialogStr("Jak myslíš, že ji zvednem?")


dialogId("disk-v-tezko", "font_big", "It will be difficult.")
dialogStr("Těžko.")


dialogId("disk-v-nejde", "font_big", "I don't think it can be done. Why would they be hiding it here, if we could lift it?")
dialogStr("Podle mě to vůbec nejde. Proč by ji sem jinak schovávali?")


dialogId("disk-v-ulamu", "font_big", "Shut up, or I will break off your pins!")
dialogStr("Buď zticha, nebo ti ulámu nožičky!")


dialogId("disk-v-kriz", "font_big", "Can you see that steel cross? This is the grave of our hopes.")
dialogStr("Vidíš ten ocelový kříž? To je hrob našich nadějí.")


dialogId("disk-m-depres", "font_small", "Don`t be always so gloomy. I can`t bear it.")
dialogStr("Nebuď pořád tak depresivní. Kdo to má poslouchat.")


dialogId("disk-m-nahrat", "font_small", "Wouldn`t it be enough to download that plan from the floppy to our notebook?")
dialogStr("Nešlo by ten plán z diskety jenom nahrát do našeho notebooku a odjet?")


dialogId("disk-v-mas", "font_big", "Why not. Take it out.")
dialogStr("Proč ne. A kde ho máš?")


dialogId("disk-m-sakra", "font_small", "Oh, darn! I left it at home.")
dialogStr("A sakra! Že já jsem ho nechala doma.")


dialogId("disk-v-vratime", "font_big", "Shall we return for it?")
dialogStr("Tak se tam vrátíme?")


dialogId("disk-v-naano", "font_big", "Never. It may seem funny to you, but my fins are sore.")
dialogStr("Tak to tedy ne. Tobě to možná připadá zábavné, ale já už mám úplně uplavané ploutve.")


dialogId("disk-v-nane", "font_big", "Suit yourself. I am curious how are you going to do it now.")
dialogStr("Jak myslíš. Tak nám tedy předveď, jak to uděláš.")


dialogId("disk-m-zmatlo", "font_small", "What if there is no plan on this floppy? What if it is here only to confound us?")
dialogStr("A co když ten plán není na té disketě? Co když je tu jen proto, aby nás to zmátlo?")


dialogId("disk-v-neverim", "font_big", "I don`t believe that. Is there some other object that would be more difficult to get out?")
dialogStr("Tomu nevěřím. Copak je tu nějaký předmět, který by bylo těžší vyndat?")


dialogId("disk-m-tvorecci", "font_small", "What kind of little creatures are those?")
dialogStr("Co je to tady za malé tvorečky?")


dialogId("disk-v-viry", "font_big", "These must be computer viruses.")
dialogStr("To jsou asi počítačové viry.")


dialogId("disk-m-potvory", "font_small", "Yuck. Some monsters.")
dialogStr("Fííí. To jsou ale potvory.")


dialogId("disk-v-pozor", "font_big", "Above all, we must be careful not to take them with the disk. The player wouldn`t be happy if we pour them on their desktop.")
dialogStr("Hlavně si musíme dát pozor, abychom je neodnesli i s disketou. To by se nám hráč poděkoval, kdybychom mu je vysypali na desktop.")


dialogId("disk-m-ukol", "font_small", "Our goal is to push out that disk.")
dialogStr("Naším úkolem je vystrčit ven tu disketu.")


dialogId("disk-x-nepohnes", "font_darkgrey", "You won`t move me easily!")
dialogStr("Se mnou jen tak nepohneš!")


dialogId("disk-x-mazany", "font_darkgrey", "That was smart!")
dialogStr("To bylo mazaný!")


dialogId("disk-x-jejda0", "font_darkgrey", "Ooops!")
dialogStr("Jejda!")


dialogId("disk-x-jejda1", "font_darkgrey", "Darn!")
dialogStr("Sakryš!")


dialogId("disk-x-au0", "font_darkgrey", "Oh.")
dialogStr("Au.")


dialogId("disk-x-au1", "font_darkgrey", "Ouch.")
dialogStr("Ouch.")


dialogId("disk-x-au2", "font_darkgrey", "Yup.")
dialogStr("Áu.")


dialogId("disk-x-uzne", "font_darkgrey", "Leave me alone!")
dialogStr("Nech mě už na pokoji!")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/floppy/dialogs_cs.lua <==

dialogId("disk-v-tady", "font_big", "It looks as if we finally got there.")
dialogStr("Zdá se, že jsme konečně tady.")


dialogId("disk-m-tady", "font_small", "Do you think this is it?")
dialogStr("Myslíš si, že je to tady?")


dialogId("disk-m-vejit", "font_small", "How could it all fit on one three and a half inch floppy?")
dialogStr("Jak by se to mohlo vejít na jednu tři a půl palcovou disketu?")


dialogId("disk-v-metrova", "font_big", "Look how much bigger than me it is. It is a three and a half meter floppy.")
dialogStr("Podívej, o kolik je to větší než já. To je spíš třiceti pěti metrová disketa.")


dialogId("disk-m-velka", "font_small", "That’s better. Big plan, big disk. That makes sense.")
dialogStr("Tak to je lepší. Velký plán, velká disketa. To dává smysl.")


dialogId("disk-m-zvednem", "font_small", "Do you think we can lift it up?")
dialogStr("Jak myslíš, že ji zvednem?")


dialogId("disk-v-tezko", "font_big", "It will be difficult.")
dialogStr("Těžko.")


dialogId("disk-v-nejde", "font_big", "I don't think it can be done. Why would they be hiding it here, if we could lift it?")
dialogStr("Podle mě to vůbec nejde. Proč by ji sem jinak schovávali?")


dialogId("disk-v-ulamu", "font_big", "Shut up, or I will break off your pins!")
dialogStr("Buď zticha, nebo ti ulámu nožičky!")


dialogId("disk-v-kriz", "font_big", "Can you see that steel cross? This is the grave of our hopes.")
dialogStr("Vidíš ten ocelový kříž? To je hrob našich nadějí.")


dialogId("disk-m-depres", "font_small", "Don’t be always so gloomy. I can’t bear it.")
dialogStr("Nebuď pořád tak depresivní. Kdo to má poslouchat.")


dialogId("disk-m-nahrat", "font_small", "Wouldn’t it be enough to download that plan from the floppy to our notebook?")
dialogStr("Nešlo by ten plán z diskety jenom nahrát do našeho notebooku a odjet?")


dialogId("disk-v-mas", "font_big", "Why not. Take it out.")
dialogStr("Proč ne. A kde ho máš?")


dialogId("disk-m-sakra", "font_small", "Oh, darn! I left it at home.")
dialogStr("A sakra! Že já jsem ho nechala doma.")


dialogId("disk-v-vratime", "font_big", "Shall we return for it?")
dialogStr("Tak se tam vrátíme?")


dialogId("disk-v-naano", "font_big", "Never. It may seem funny to you, but my fins are sore.")
dialogStr("Tak to tedy ne. Tobě to možná připadá zábavné, ale já už mám úplně uplavané ploutve.")


dialogId("disk-v-nane", "font_big", "Suit yourself. I am curious how are you going to do it now.")
dialogStr("Jak myslíš. Tak nám tedy předveď, jak to uděláš.")


dialogId("disk-m-zmatlo", "font_small", "What if there is no plan on this floppy? What if it is here only to confound us?")
dialogStr("A co když ten plán není na té disketě? Co když je tu jen proto, aby nás to zmátlo?")


dialogId("disk-v-neverim", "font_big", "I don’t believe that. Is there some other object that would be more difficult to get out?")
dialogStr("Tomu nevěřím. Copak je tu nějaký předmět, který by bylo těžší vyndat?")


dialogId("disk-m-tvorecci", "font_small", "What kind of little creatures are those?")
dialogStr("Co je to tady za malé tvorečky?")


dialogId("disk-v-viry", "font_big", "These must be computer viruses.")
dialogStr("To jsou asi počítačové viry.")


dialogId("disk-m-potvory", "font_small", "Yuck. Some monsters.")
dialogStr("Fííí. To jsou ale potvory.")


dialogId("disk-v-pozor", "font_big", "Above all, we must be careful not to take them with the disk. The player wouldn’t be happy if we pour them on their desktop.")
dialogStr("Hlavně si musíme dát pozor, abychom je neodnesli i s disketou. To by se nám hráč poděkoval, kdybychom mu je vysypali na desktop.")


dialogId("disk-m-ukol", "font_small", "Our goal is to push out that disk.")
dialogStr("Naším úkolem je vystrčit ven tu disketu.")


dialogId("disk-x-nepohnes", "font_darkgrey", "You won’t move me easily!")
dialogStr("Se mnou jen tak nepohneš!")


dialogId("disk-x-mazany", "font_darkgrey", "That was smart!")
dialogStr("To bylo mazaný!")


dialogId("disk-x-jejda0", "font_darkgrey", "Ooops!")
dialogStr("Jejda!")


dialogId("disk-x-jejda1", "font_darkgrey", "Darn!")
dialogStr("Sakryš!")


dialogId("disk-x-au0", "font_darkgrey", "Oh.")
dialogStr("Au.")


dialogId("disk-x-au1", "font_darkgrey", "Ouch.")
dialogStr("Ouch.")


dialogId("disk-x-au2", "font_darkgrey", "Yup.")
dialogStr("Áu.")


dialogId("disk-x-uzne", "font_darkgrey", "Leave me alone!")
dialogStr("Nech mě už na pokoji!")
